@@ -465,7 +465,6 @@ class CipherTestCase(unittest.TestCase):
 
         for key_size in [128, 192, 256]:
             alg = 'aes_%s_ctr' % str(key_size)
-            log.info('Testing cipher %s', alg)
 
             # Our key for this test is 256 bits in length (32 bytes).
             # We will trim it to the appopriate length for testing AES-128
@@ -518,6 +517,11 @@ class CipherTestCase(unittest.TestCase):
                 unhexlify('5cd148eeaf680d4ff933aed83009cad4110162f53ef89fd44fad09611b0524d4'),
                 unhexlify(''))
 
+    def test_cipher_init_reinit(self):
+        ctx = m2.cipher_ctx_new()
+        m2.cipher_init(ctx, m2.aes_128_cbc(), b'\x01' * (128//8), b'\x02' * (128//8), 1)
+        m2.cipher_init(ctx, m2.aes_128_cbc(), None, None, 1)
+
 
 class PBKDF2TestCase(unittest.TestCase):
     def test_rfc3211_test_vectors(self):
