@@ -19,7 +19,7 @@ class CheckerTestCase(unittest.TestCase):
 
         check = SSL.Checker.Checker(
             host=srv_host,
-            peerCertHash='0C6BBAFAD2D6F775C38596399E6C4E5680A701C2')
+            peerCertHash='86C01325EFBC44098723CC1567EB75A68727A3D6')
         x509 = X509.load_cert('tests/server.pem')
         self.assertTrue(check(x509, srv_host))
         with self.assertRaises(SSL.Checker.WrongHost):
