@@ -15,7 +15,7 @@ import os
 import time
 import warnings
 
-from M2Crypto import ASN1, BIO, EVP, RSA, Rand, X509, m2  # noqa
+from M2Crypto import ASN1, BIO, EVP, RSA, Rand, X509, m2, six  # noqa
 from tests import unittest
 
 log = logging.getLogger(__name__)
@@ -27,7 +27,7 @@ class X509TestCase(unittest.TestCase):
         pass
 
     def setUp(self):
-        self.expected_hash = 'F0429E180321BB3C0CBEAB811360BB0E27CC0259'
+        self.expected_hash = 'BA4212E8B55527570828E7F5A0005D17C64BDC4C'
 
     def mkreq(self, bits, ca=0):
         pk = EVP.PKey()
@@ -566,6 +566,12 @@ class X509TestCase(unittest.TestCase):
         self.assertEqual(cert.get_serial_number(),
                          127614157056681299805556476275995414779)
 
+    def test_set_long_serial(self):
+        cert = X509.X509()
+        cert.set_serial_number(127614157056681299805556476275995414779)
+        self.assertEqual(cert.get_serial_number(),
+                         127614157056681299805556476275995414779)
+
     def test_date_after_2050_working(self):
         cert = X509.load_cert('tests/bad_date_cert.crt')
         self.assertEqual(str(cert.get_not_after()), 'Feb  9 14:57:46 2116 GMT')
@@ -586,7 +592,10 @@ class X509StackTestCase(unittest.TestCase):
 
         with warnings.catch_warnings():
             warnings.simplefilter('ignore', DeprecationWarning)
-            seq = base64.decodestring(b64)
+            if six.PY3:
+                seq = base64.decodebytes(b64)
+            else:
+                seq = base64.decodestring(b64)
 
         stack = X509.new_stack_from_der(seq)
         cert = stack.pop()
@@ -606,7 +615,10 @@ class X509StackTestCase(unittest.TestCase):
 
         with warnings.catch_warnings():
             warnings.simplefilter('ignore', DeprecationWarning)
-            seq = base64.decodestring(b64)
+            if six.PY3:
+                seq = base64.decodebytes(b64)
+            else:
+                seq = base64.decodestring(b64)
 
         stack = X509.new_stack_from_der(seq)
         num = len(stack)
